from django.db import models
from custom.models import *

# Create your models here.
class National(models.Model):
	name = models.CharField(max_length=200, null=True, verbose_name="Nasional")
	code = models.CharField(max_length=10, null=True, blank=True)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)

	class Meta:
		verbose_name_plural='Dadus Custom Ba Nasional'

class ONG(models.Model):
	name = models.CharField(max_length=30, null=True,verbose_name="ONG")

	def __str__(self):
		template = '{0.name}'
		return template.format(self)
	class Meta:
		verbose_name_plural='Dadus Custom Ba ONG'

class Agency(models.Model):
	name = models.CharField(max_length=30, null=True, verbose_name="Ajénsia")

	def __str__(self):
		template = '{0.name}'
		return template.format(self)

	class Meta:
		verbose_name_plural='Dadus Custom Ba Ajénsia'

class Company(models.Model):
	name = models.CharField(max_length=300, null=True)

	def __str__(self):
		return self.name

	class Meta:
		verbose_name_plural=' Dadus Custom Ba Kompañia' 




from django.contrib import admin
from .models import *

# Register your models here.

from import_export import resources

from import_export.admin import ImportExportModelAdmin


class AgencyResource(resources.ModelResource):
    class Meta:
        model = Agency
class AgencyAdmin(ImportExportModelAdmin):
    resource_class = AgencyResource
admin.site.register(Agency, AgencyAdmin)


class NationalResource(resources.ModelResource):
    class Meta:
        model = National
class NationalAdmin(ImportExportModelAdmin):
    resource_class = NationalResource
admin.site.register(National, NationalAdmin)

class CompanyResource(resources.ModelResource):
    class Meta:
        model = Company
class CompanyAdmin(ImportExportModelAdmin):
    resource_class = CompanyResource
admin.site.register(Company, CompanyAdmin)



class ONGResource(resources.ModelResource):
    class Meta:
        model = ONG
class ONGAdmin(ImportExportModelAdmin):
    resource_class = ONGResource
admin.site.register(ONG, ONGAdmin)




from django.apps import AppConfig


class CustomDevelopmentConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'custom_development'
    verbose_name = 'Dadus Custom Ba Livru Administrasaun Dezenvolvimentu'
